<?php
/**
 * Hoot Premium Extension
 *
 * @package    Unos Magazine Vu
 */

/**
 * Custom CSS built from user theme options
 * For proper sanitization, always use functions from library/sanitization.php
 * Priority@6: 5-> base lite ; 7-> base prim prepare (rules removed) ;
 *             9-> base prim ; 10-> base hootkit lite/prim
 *
 * @since 1.0
 * @access public
 */
function unosmvu_premium_dynamic_cssrules() {

	global $hoot_style_builder;

	// Get user based style values
	$styles = unos_user_style(); // echo '<!-- '; print_r($styles); echo ' -->';
	extract( $styles );

	hoot_add_css_rule( array(
						'selector'  => '.post-footer',
						'property'  => array(
							'background'   => array( $footer_background_color ),
							'color'        => array( $font_footer_color ),
							),
					) );

}
add_action( 'hoot_dynamic_cssrules', 'unosmvu_premium_dynamic_cssrules', 10 );

/**
 * Update theme defaults
 * Prim @priority 5
 * Lite child @priority 7
 *
 * @since 1.0
 * @access public
 * @return array
 */
function unosmvu_default_premium_style( $defaults ){
	$defaults = array_merge( $defaults, array(
		// // 'site_background_patt'       => 'hoot/images/patterns/4.png',
		// // 'site_background_type'       => 'custom',
		// // 'site_background_image'      => hoot_data()->template_uri . 'images/background.jpg',
		// // 'site_background_size'       => 'cover',
		// // 'site_background_repeat'     => 'no-repeat',
		// // 'site_background_attachment' => 'fixed',
		'menu_icons_color'           => '#000000',
		// 'topbar_background_type'     => 'background',
		'topbar_background'          => '#ff4530',
		// 'header_background'          => '#ffffff',
		// 'logo_background'            => '#ffffff',
		// 'menu_background'            => '#ffffff',
		// 'menu_dropdown_background'   => '#ffffff',
		// 'pageheader_background'      => '#f5f5f5',
		// 'subfooter_background'       => '#f5f5f5',
		'footer_background'          => '#f5f5f5',
		'topbar_color'               => '#ffffff',
		'font_logo_size'             => '50px',
		// 'font_logo_face'             => '"Lora", serif',
		'font_logo_style'            => 'uppercase',
		// 'font_logo_color'            => '#222222',
		// 'font_tagline_size'          => '13px',
		// 'font_tagline_face'          => '"Open Sans", sans-serif',
		// 'font_tagline_style'         => 'none',
		// 'font_tagline_color'         => '#444444',
		// 'font_nav_menu_size'         => '14px',
		// 'font_nav_menu_face'         => '"Open Sans", sans-serif',
		// 'font_nav_menu_style'        => 'uppercase semibold',
		// 'font_nav_menu_color'        => '#222222',
		// 'font_nav_dropdown_size'     => '13px',
		// 'font_nav_dropdown_style'    => 'none',
		// 'font_nav_dropdown_color'    => '#666666',
		// 'font_body_size'             => '15px',
		// 'font_body_face'             => '"Open Sans", sans-serif',
		// 'font_body_style'            => 'none',
		// 'font_body_color'            => '#666666',
		'link_color'                 => '#ff4530',
		'link_hover_color'           => '#c3301f',
		'font_h3_size'               => '20px',
		// 'font_h3_face'               => '"Lora", serif',
		'font_h3_style'              => 'none',
		// 'font_h3_color'              => '#222222',
		// 'font_h1_size'               => '30px',
		'font_h1_style'              => 'none',
		// 'font_h1_color'              => '#222222',
		// 'font_h2_size'               => '26px',
		'font_h2_style'              => 'none',
		// 'font_h2_color'              => '#222222',
		// 'font_h4_size'               => '20px',
		'font_h4_style'              => 'none',
		// 'font_h4_color'              => '#222222',
		// 'font_h5_size'               => '18px',
		'font_h5_style'              => 'none',
		// 'font_h5_color'              => '#222222',
		// 'font_h6_size'               => '16px',
		'font_h6_style'              => 'none',
		// 'font_h6_color'              => '#222222',
		// 'font_sidebar_heading_size'  => '15px',
		// 'font_sidebar_heading_face'  => '"Open Sans", sans-serif',
		// 'font_sidebar_heading_style' => 'uppercase',
		// // 'font_sidebar_heading_color' => '#ffffff',
		// 'font_sidebar_size'          => '15px',
		// 'font_sidebar_style'         => 'none',
		// 'font_sidebar_color'         => '#666666',
		// 'font_footer_heading_size'   => '15px',
		// 'font_footer_heading_face'   => '"Open Sans", sans-serif',
		// 'font_footer_heading_style'  => 'uppercase',
		// // 'font_footer_heading_color'  => '#ffffff',
		// 'font_footer_size'           => '15px',
		// 'font_footer_style'          => 'none',
		// 'font_footer_color'          => '#666666',
	) );
	return $defaults;
}
add_filter( 'unos_default_style', 'unosmvu_default_premium_style', 9 );

/**
 * Remove the filter (to append google fonts) and let those fonts occur in their natural order as in hoot_googlefonts_list()
 */
remove_filter( 'hoot_fonts_list', 'unosmvu_fonts_list', 15 );

/**
 * Modify the image thumbnail size for mosaic 3/4 archive styles
 *
 * @since 1.0
 * @access public
 * @return string
 */
if ( !function_exists( 'unosmvu_archive_imgsize' ) ):
function unosmvu_archive_imgsize( $size, $context='' ){
	if ( $context == 'mosaic3' || $context == 'mosaic4' ) $size = 'hoot-preview-thumb';
	return $size;
}
endif;
add_filter( 'unos_archive_imgsize', 'unosmvu_archive_imgsize', 7, 2 );

/**
 * Update OCDI Import Files
 *
 * @since 1.0
 * @return array
 */
function unosmvu_ocdi_import() {
	$files = array(
		array(
			'import_file_name'           => __( 'Unos Magazine Vu Demo', 'unos-magazine-vu' ),
			'import_file_url'            => 'https://demo.wphoot.com/downloads/unos-magazine-vu-content-free.xml',
			'import_widget_file_url'     => 'https://demo.wphoot.com/downloads/unos-magazine-vu-widgets-free.wie',
			'import_customizer_file_url' => 'https://demo.wphoot.com/downloads/unos-magazine-vu-customize-free.dat',
			'import_preview_image_url'   => hoot_data()->child_uri . 'screenshot.jpg',
			/* Translators: The %s are placeholders for HTML, so the order can't be changed. */
			'import_notice'              => sprintf( esc_html__( 'You are using the free version of the theme.%1$sSome features (available only in the premium version) will not get imported - You may see %2$s"Could not import"%3$s message for these features in the log once the installation is finished. You can safely ignore these messages.', 'unos-magazine-vu' ), '<br />', '<em>', '</em>' ),
			'preview_url'                => 'https://demo.wphoot.com/unos-magazine-vu/',
		),
	);
	if ( function_exists( 'hoot_lib_premium_core' ) ) {
		if ( isset( $files[0]['import_notice'] ) ) unset( $files[0]['import_notice'] );
		if ( isset( $files[0]['import_file_url'] ) ) $files[0]['import_file_url'] = str_replace( '-free', '', $files[0]['import_file_url'] );
		if ( isset( $files[0]['import_widget_file_url'] ) ) $files[0]['import_widget_file_url'] = str_replace( '-free', '', $files[0]['import_widget_file_url'] );
		if ( isset( $files[0]['import_customizer_file_url'] ) ) $files[0]['import_customizer_file_url'] = str_replace( '-free', '', $files[0]['import_customizer_file_url'] );
	}
	return $files;
}
add_filter( 'pt-ocdi/import_files', 'unosmvu_ocdi_import', 15 );